import { __awaiter, __decorate } from "tslib";
import { inIFrame, inSymphonyDesktop, openPopup } from '@genesislcap/foundation-utils';
import { customElement, DOM, volatile } from '@microsoft/fast-element';
import { CredentialManager, CredentialType } from '../../credential';
import { User } from '../../user';
import { getSSOLoginURL, logger } from '../../utils';
import { BaseRoute } from '../base';
import { LoginStyles as styles } from './login.styles';
import { LoginTemplate as template } from './login.template';
let Login = class Login extends BaseRoute {
    connectedCallback() {
        super.connectedCallback();
        /**
         * Retaining the logic that logs authenticated users out when this route is visited for now.
         * TODO: Revisit as shouldn't load mf if logged in already.
         */
        if (this.user.isAuthenticated) {
            this.logout();
            return;
        }
        this.attemptAutofill();
    }
    attemptBasicLogin() {
        const basicCredentials = {
            type: CredentialType.BASIC,
            username: this.store.formEntry.username,
            password: this.store.formEntry.password,
        };
        if (!this.credentialManager.validateBasicCredentials(basicCredentials)) {
            logger.debug(`Basic credentials appear invalid, aborting login attempt.`);
            return;
        }
        logger.debug(`Attempting to login with basic credentials.`);
        this.login(basicCredentials);
    }
    get ssoToggleLabel() {
        const { selectedIDP, ssoToggled } = this.store.formEntry;
        const selectedIDPLabel = selectedIDP ? ` - ${selectedIDP}` : '';
        return ssoToggled ? 'SSO Enabled' + selectedIDPLabel : 'Enable SSO?';
    }
    onSSOLogin() {
        const selectedIDP = this.store.formEntry.idps.find((idp) => idp.id === this.store.formEntry.selectedIDP);
        const ssoLoginUrl = getSSOLoginURL(selectedIDP);
        if (inIFrame()) {
            if (inSymphonyDesktop()) {
                // symphony/electron opens new window in the default browser instead
                // popup within electron, so we have to navigate manually
                openPopup('', 'symphony').location.assign(ssoLoginUrl);
            }
            else {
                openPopup(ssoLoginUrl, 'Login');
            }
        }
        else {
            window.open(ssoLoginUrl, '_self');
        }
    }
    onLoginSubmit() {
        return __awaiter(this, void 0, void 0, function* () {
            DOM.queueUpdate(() => {
                this.attemptBasicLogin();
            });
        });
    }
    login(params) {
        this.$emit('auth-login', params);
    }
    logout() {
        this.$emit('auth-logout');
    }
    get submitDisabled() {
        return this.store.authMachine.hasTag('pending');
    }
};
__decorate([
    User
], Login.prototype, "user", void 0);
__decorate([
    CredentialManager
], Login.prototype, "credentialManager", void 0);
__decorate([
    volatile
], Login.prototype, "ssoToggleLabel", null);
Login = __decorate([
    customElement({
        name: 'foundation-auth-login',
        template,
        styles,
    })
], Login);
export { Login };
